#!/bin/csh

#
# This is the script that performs apodization, Fourier transformation,
# baseline correction, etc.  It operates as a standard nmrPipe script
# except for the loop, which allows the same transformations to proceed
# on both the reference and attenuated spectra.
#

set tauValues = ( 5.343 10.673 )    # evolution times for each QJ point
set idxExpmt  = (     1      2 )    # (you don't need to change these
                                    # lines if you use get_jnh.py)

rm -rf ft ft2d
mkdir ft

foreach n ( `seq 1 ${#tauValues}` )
  echo Time t${n} \($tauValues[$n] ms\)...
  set outName  = (`printf ft/test%03d.ft2 $n`)
  set ucsfName = (`printf ./dnh_t%03d.ucsf $n`)
  set inName   = (`printf fid/test%03d.fid $idxExpmt[$n]`)
  echo "* input  = $inName"
  echo "* output = $outName"

  nmrPipe -in $inName \
  | nmrPipe  -fn POLY -time                             \
  | nmrPipe  -fn SP -off 0.5 -end 0.98 -pow 2 -c 0.5    \
  | nmrPipe  -fn ZF -size 4096                          \
  | nmrPipe  -fn FT                                     \
  | nmrPipe  -fn EXT -x1 11ppm -xn 6ppm -sw -verb       \
  | nmrPipe  -fn PS -p0 36.2 -p1 -1.0 -di               \
  | nmrPipe  -fn TP                                     \
  | nmrPipe  -fn SP -off 0.5 -end 0.98 -pow 1 -c 0.5    \
  | nmrPipe  -fn ZF -size 2048                          \
  | nmrPipe  -fn FT                                     \
  | nmrPipe  -fn PS -p0 91.0 -p1 0.0 -di                \
  | nmrPipe  -fn TP                                     \
  | nmrPipe  -fn POLY -auto -ord 2                      \
     -verb -ov -out $outName

  # Optional: Make Sparky-format spectra
  #pipe2ucsf $outName $ucsfName

  sethdr $outName -tau $tauValues[$n]
end

# Backup the 2D spectra (solely for use with IPAP.  ugh.)
cp -r ft ft2d

# Make the 2D's into a psuedo 3D
series.com ft/test*.ft2
