;
; title:   artsy-qjnh.pp
; summary: ARTSY-2D TROSY for measuring JNH
; author:  Nick Fitzkee (nfitzkee@nih.gov)
; date:    June 29, 2010
; version: 6 (final version)
;
; See footer below for notes.
;
; Changes:
; 5.0   - Works w/ simultaenous 180's, confirmed with epsilon ~ 30 us
; 6.0   - Offset the 180 pulses during first inept, corrected delay
;

#include <Avance.incl>
#include <Grad.incl>
#include <Delay.incl>

;--- SWITCH -----
#define CARBON_LABEL
#define INTERLEAVE

#define H f1
#define N f3
#define C1 f2    ; 13C centered at 56 ppm (if available)
#define C2 f2    ; 13C centered at 176 ppm

define pulse PG1
define pulse PG3
define pulse PG4
define pulse PG5
define pulse PG6
define pulse PG7

;Gradient Pulses
"PG1=1m"       ;half-encoding
"PG3=500u"
"PG4=500u"     ;half-encoding
"PG5=250u"
"PG6=800u"
"PG7=101.3u"   ;decoding

"l5=1"
"l6=1"

"d0=3u"                          ;use if set up for (0,0) 15N phase

#ifdef CARBON_LABEL
"DELTA4=p14*2+4u+d0*2+p21*1.274-p1"   ;phc0=0 phc1=0 aliased peaks same sign
;"d0=in0*0.5-p21*0.637-2u-p14+p1*0.5" ;ph0=90deg ph1=-180deg
#else
"DELTA4=d0*2+2u+p21*1.274-p1"    ;phc0=0 phc1=0  aliased peaks same sign
;"d0=in0*0.5-p21*0.637-1u"       ;ph0=90deg ph1=-180deg
#endif
                                 ;note well:  will still require a little 
                                 ;            phase correction in 15N and;
                                 ;            will not likely be perfect for 
                                 ;            all peaks.  This is due to
                                 ;            sequence design.
"p2=p1*2"
"p22=p21*2"

"d11=30m"
"d12=100u"
"d16=190u"                       ;Gradient recovery
"d28=p6+5u+p1-p21"

; Delays to compensate composite 15N 180
"d29=p21*4.34"

; Adjust for Clean TROSY (with phcor14) - total time for 1st S3E element
"d25=2.71m"

; Total time of 1st transfer step (1/JNH)
; Adjust this so 2nd FID is a null for isotropic sample
; In the attenuated spectrum, the coupling will evolve for d27, and in
; the reference spectrum, it will evolve for d27*0.5 + 0.637*p1.
"d27=10.75m"

"DELTA1=d27-d29*3-p1*1.237-80u"
"DELTA2=d25-PG5-p29-d16"
"DELTA3=2.71m-PG6-p6-205u"
"DELTA5=300u-PG7-20u-p1-3u"

; Comment out when multiple SGUs in use for C1/C2
; You will need to set the offset of sp3 manually (to 56 ppm)
"cnst21=176"
"cnst22=56"
"spoff3=bf2*((cnst22-cnst21)/1000000)"
"spoff5=0"


1       ze
        1m 
2       10u do:C2
        1m BLKGRAD
        d11
        d12*6
3       d12*6
4       d12*6
5       d1 
        1m UNBLKGRAD 
        10u pl0:H
        10u pl3:N
        10u pl0:C1
        10u pl0:C2

;- start 90-degree on hn --------------------------------------

       (p21 ph0):N              ; along with cycling ph5,
        3u                      ; this thoroughly eliminates 
        PG1:gp1                 ; 15N Boltzmann magnetization
        500u

       (p29:sp12 ph11:r):H
        3u 
        3u pl1:H
10     (p1 ph5):H
        5u
        5u gron2
        DELTA1*0.25 
        10u groff
        d29*2
        5u
        5u gron2
        DELTA1*0.25 
        10u groff

        if "l6==1" goto 20
       (p2 ph0):H 
       (p21 ph0 p21*2.34 ph1 p21 ph0):N
        5u
        5u gron2
        DELTA1*0.25
        10u groff
        d29
        goto 25

20     (p2 ph0):H
        d29*0.75
        5u
        5u gron2
        DELTA1*0.25 
        10u groff
       (p21 ph0 p21*2.34 ph1 p21 ph0):N        
        d29*0.25

25      5u
        5u gron2
        DELTA1*0.25 
        10u groff
       (p1 ph1):H
30      3u

;goto 100               ;WARNING - make sure pl12 is set properly for C' dec
;                                  or comment out C' AQ cpd before using this
;                                  statement.  Ditto for all 'goto 100's'.
        PG3:gp3
        d16 

;- quantitative-J finished, start 15N evolution ---------------

       if "l5==1" {
       (p25 ph17):N
        } else {
       (p21 ph7):N
        }
        d0

#ifdef CARBON_LABEL
       (p14:sp3 ph0):C1
        4u
       (p14:sp5 ph0):C2
#else
        2u
#endif
        d0

        PG4:gp4*EA        ;half-encoding pulse
        200u
       if "l5==1" {
       (p22 ph17):N
         } else {
       (p22 ph7):N
         }
        PG4:gp4*EA*-1     ;half-encoding pulse
        200u
        DELTA4            ;comment out if 90,180 delay selected

;- start final TROSY back-transfer ----------------------------

       (p1 ph12):H
        3u 
        2u pl0:H
       (p29:sp1 ph21:r):H
;goto 100
        5u 
        PG5:gp5
        DELTA2 
        d16 pl1:H
       (center (p2 ph0):H (p22 ph0):N)
        5u
        DELTA2
        PG5:gp5
        d16 pl0:H
       (p29:sp2 ph22:r):H
        3u 
        2u pl1:H
       (p1 ph0):H (p21 ph15):N
        5u
;goto 100
        PG6:gp6           
        195u pl7:H
        DELTA3
       (150u p6 ph10:r 3u 2u pl1 p2 ph0 3u 2u pl7 p6 ph10:r):H (d28 p22 ph15):N
        3u 
        2u pl1:H
;goto 100
        PG6:gp6
        DELTA3
        45u
       (p21 ph14:r):N
        3u
        PG7:gp7               ;decoding gradient
        DELTA5
100     5u
        5u pl12:C2
        10u BLKGRAD
#ifdef CARBON_LABEL
        go=2 ph31 cpds2:C2
#else 
        go=2 ph31
#endif         
        10u do:C2
        1m BLKGRAD
        d11 wr #0 if #0 zd
#ifdef INTERLEAVE
        d12*6 iu6
       lo to 3 times 2
#else
        d12*6
#endif
        d12 igrad EA
        d12 ip12*2
        d12 ip21*2
        d12 ip14*2
        d12 iu5
        d12 ru6
       lo to 4 times 2
        d12 ip7*2
        d12 ip17*2
        d12 ip31*2
        d12 id0
        d12 ru5
        d12
       lo to 5 times l3

1m do:C1
1m do:N
1m BLKGRAD 
exit    
        
ph0=0
ph1=1
ph2=2
ph3=3

ph5=0 2
ph7=1 1 3 3
ph10=2
ph11=3
ph12=3
ph14=3 3 3 3 1 1 1 1
ph15=0 0 0 0 2 2 2 2
ph17=1 1 3 3
ph21=1
ph22=0
ph31=1 3 3 1 3 1 1 3


;---- NOTES ----- 

; tested on Bruker AVIII TS2-PL3 consoles
; Note: when used on older dmx/drx consoles, add 3u between pulses
; in the 15N composite pulse (and adjust d29, d30)

; All "goto 100" statements are at points where water flip-backs can
; be tuned.  See note above at first statement.

;1H pulses (H=f1, center on H2O):
;p1 = 90 deg (10us) hard 1H pulse @ pl1
;p6 = 1.2ms soft 90 deg pulse @ pl7
;p29 = 1.9m @ sp1, sp2, and sp12  (spnam1 = sinc1.0)

;15N pulses (N=f3, carrier=119ppm):
;p21 = 90 deg (~50us) 15N pulse @pl3

;13C pulses (C1=C2=f2, carrier=176ppm; must modify for two channels):
;p14 = selective 180 deg (23.7*2us @ 600MHz)
;spnam3 and spnam5 = RECT.1000  (~1000 points req'd for spoffs)
;cpdprg2 = garp  (aq C' dec program for 13C samples)
;pcpd2   = pw for C' aq dec (140u) @ pl12

;N  SW = 1/(2*in0)
;echo-antiecho in N15

;RECT pulse pairs do not work well on an AVIII
;gpz1 = +33%  sine.100   Boltzmann killer
;gpz2 = +0.5  (gron2)
;gpz3 = +17%  sine.100   zz crusher gradient
;gpz4 = +70%  sine.20    encoding gradient
;gpz5 = +15%  sine.50
;gpz6 = +23%  sine.50
;gpz7 = +70%  sine.20    decoding gradient
